package App::EditorTools;

use strict;
use warnings;

use App::Cmd::Setup -app;

our $VERSION = 0.03;

=pod

=head1 NAME

App::EditorTools - Command line tools to leverage PPIx::EditorTools (and maybe more)

=head1 SYNOPSIS

    See PPIx::EditorTools::* 

=head1 DESCRIPTION

Command line tools to leverage PPIx::EditorTools (and maybe more) for 
editors that need the command line go between.

=cut

1;

__END__

=head1 SEE ALSO

L<PPIx::EditorTools>, L<Padre>

=head1 BUGS

Please report any bugs or suggestions at 
L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-EditorTools>

=head1 AUTHOR

Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2009 by Mark Grimes

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.2 or,
at your option, any later version of Perl 5 you may have available.

